pub fn py_bar_spec_to_tardis_trade_bar_string(
bar_spec: &BarSpecification,
) -> PyResult<String>Expand description
Converts a bar specification to a Tardis trade bar string.
Errors
Returns an error if the bar specification cannot be converted to a Tardis format.